jacinle.web.session
===================

.. automodule:: jacinle.web.session

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      InMemorySessionManager
      KVBasedSessionManager
      MemcachedSessionManager
      Session
      SessionIdentifier
      SessionManagerBase
   
   

   
   
   

   
   
   








.. rubric:: Class InMemorySessionManager
.. autoclass:: InMemorySessionManager
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class KVBasedSessionManager
.. autoclass:: KVBasedSessionManager
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class MemcachedSessionManager
.. autoclass:: MemcachedSessionManager
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class Session
.. autoclass:: Session
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class SessionIdentifier
.. autoclass:: SessionIdentifier
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__


.. rubric:: Class SessionManagerBase
.. autoclass:: SessionManagerBase
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







